import React, { useState, useEffect } from 'react';


  const LocationDetails = ({ onDataUpdate, initialData = {} }) => {
    const [locationData, setLocationData] = useState({
      city: initialData.city || '',
      locality: initialData.locality || '',
      subLocality: initialData.subLocality || '',
      detailedAddress: initialData.detailedAddress || ''
    });

  /*useEffect(() => {
    onDataUpdate({
      city: locationData.city,
      locality: locationData.locality,
      subLocality: locationData.subLocality,
      detailedAddress: locationData.detailedAddress
    });
  }, [locationData, onDataUpdate]); */


  useEffect(() => {
    console.log('LocationDetails updating with:', locationData); // Add this log
    onDataUpdate(locationData);
  }, [locationData, onDataUpdate]);
  


  /*const handleInputChange = (e) => {
    const { name, value } = e.target;
    setLocationData(prevData => ({
      ...prevData,
      [name]: value
    }));
  }; */

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    console.log(`Updating ${name} with value:`, value); // Add this log
    setLocationData(prevData => ({
      ...prevData,
      [name]: value
    }));
  };

  

  return (
    <div className="w-full">
      <h2 className="text-xl font-bold sm:text-2xl mb-6">Where is your Land Located?</h2>
      <p className="text-gray-600 mb-6">Providing an accurate location helps you connect with the right buyers.</p>
      
      <div className="space-y-6">
        <div className="grid gap-4 sm:grid-cols-2">
          <div>
            <label className="mb-2 block font-medium">City</label>
            <input
              type="text"
              name="city"
              placeholder="Enter city name"
              value={locationData.city}
              onChange={handleInputChange}
              className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
            />
          </div>
          <div>
            <label className="mb-2 block font-medium">Locality</label>
            <input
              type="text"
              name="locality"
              placeholder="Enter locality"
              value={locationData.locality}
              onChange={handleInputChange}
              className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
            />
          </div>
        </div>

        <div>
          <label className="mb-2 block font-medium">Address in Details</label>
          <textarea
            name="detailedAddress"
            placeholder="Enter detailed address"
            value={locationData.detailedAddress}
            onChange={handleInputChange}
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5 resize-none"
            rows={3}
          />
        </div>

        <div>
          <label className="mb-2 block font-medium">Sub Locality (optional)</label>
          <input
            type="text"
            name="subLocality"
            placeholder="Enter sub locality"
            value={locationData.subLocality}
            onChange={handleInputChange}
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
          />
        </div>
      </div>
    </div>
  );
};

export default LocationDetails;